@@ -40,7 +40,7 @@ ALL_SERVICES = DEFAULT_SERVICES + [
     'monitor',
     'worker-manager-cpu',
     'worker-manager-gpu',
-    'worker-singularity',
+    'worker2',
 ]
 
 ALL_NO_SERVICES = [
@@ -58,7 +58,7 @@ SERVICE_TO_IMAGE = {
     'worker-manager-gpu': 'server',
     'monitor': 'server',
     'worker': 'worker',
-    'worker-singularity': 'worker',
+    'worker2': 'worker',
 }
 
 # Max timeout in seconds to wait for request to a service to get through
@@ -317,12 +317,6 @@ CODALAB_ARGUMENTS = [
         type=int,
         default=10 * 60,
     ),
-    CodalabArg(
-        name='worker_manager_seconds_between_workers',
-        help='Number of seconds to wait between launching two workers',
-        type=int,
-        default=60,
-    ),
     CodalabArg(
         name='worker_manager_sleep_time_seconds',
         help='Number of seconds to wait between checks',
@@ -350,21 +344,6 @@ CODALAB_ARGUMENTS = [
         type=str,
         help='Azure Batch service url for the Azure Batch worker manager',
     ),
-    CodalabArg(
-        name='worker_manager_kubernetes_cluster_host',
-        type=str,
-        help='Host address of the Kubernetes cluster for the Kubernetes worker manager',
-    ),
-    CodalabArg(
-        name='worker_manager_kubernetes_auth_token',
-        type=str,
-        help='Kubernetes cluster authorization token for the Kubernetes worker manager',
-    ),
-    CodalabArg(
-        name='worker_manager_kubernetes_cert_path',
-        type=str,
-        help='Path to the generated SSL cert for the Kubernetes worker manager',
-    ),
     CodalabArg(
         name='worker_manager_aws_region',
         type=str,
@@ -397,10 +376,20 @@ CODALAB_ARGUMENTS = [
         default='/tmp/codalab/link-mounts',
     ),
     CodalabArg(name='azure_blob_connection_string', help='Azure Blob storage connection string'),
+    CodalabArg(
+        name='google_application_credentials',
+        help='Path to Google Application Credentials file.',
+        # TODO: find a better default that is a no-op (we need a default value in order for docker-compose to mount this properly).
+        default='./codalab_service.py',
+    ),
     CodalabArg(
         name='always_use_azure_blob_beta',
         help='If set, Azure Blob Storage is always used to store uploads, regardless of the use_azure_blob_beta parameter.',
     ),
+    CodalabArg(
+        name='default_bundle_store_name',
+        help='If set, bundles are uploaded by default to the bundle store with this name if no bundle store is provided.',
+    ),
     # Public workers
     CodalabArg(name='public_workers', help='Comma-separated list of worker ids to monitor'),
     CodalabArg(
@@ -479,6 +468,27 @@ for worker_manager_type in ['cpu', 'gpu']:
             type=int,
             default=1,
         ),
+        CodalabArg(
+            name=f'worker_manager_{worker_manager_type}_seconds_between_workers',
+            help=f'Number of seconds to wait between launching two {worker_manager_type} workers',
+            type=int,
+            default=60,
+        ),
+        CodalabArg(
+            name=f'worker_manager_{worker_manager_type}_kubernetes_cluster_host',
+            type=str,
+            help='Host address of the Kubernetes cluster for the Kubernetes worker manager',
+        ),
+        CodalabArg(
+            name=f'worker_manager_{worker_manager_type}_kubernetes_auth_token',
+            type=str,
+            help='Kubernetes cluster authorization token for the Kubernetes worker manager',
+        ),
+        CodalabArg(
+            name=f'worker_manager_{worker_manager_type}_kubernetes_cert_path',
+            type=str,
+            help='Path to the generated SSL cert for the Kubernetes worker manager',
+        ),
     ]
 
 
@@ -831,7 +841,7 @@ class CodalabServiceManager(object):
     def bring_up_service(self, service):
         if should_run_service(self.args, service):
             print_header('Bringing up {}'.format(service))
-            self._run_compose_cmd('up -d --no-deps %s' % service)
+            self._run_compose_cmd('up --force-recreate -d --no-deps %s' % service)
 
     def run_service_cmd(self, cmd, root=False, service='rest-server'):
         if root:
@@ -942,7 +952,7 @@ class CodalabServiceManager(object):
             self.bring_up_service('worker-shared-file-system')
         else:
             self.bring_up_service('worker')
-        self.bring_up_service('worker-singularity')
+        self.bring_up_service('worker2')
 
         self.bring_up_service('monitor')
 
